/******************************************************
VS-RC003 SDK 
Originaly written by Vstone
Mainteined by Kumotek for the customer outside Japan

Updated by Masahiro 2011/04/13
	re-wrote comment in english
********************************************************/


/*-----DLL Export-----*/
#define EXPORT extern "C" __declspec(dllexport)

/*---Enum that represents return value from functions---*/
typedef enum{
	ERR_MOTION_NOTFOUND=1,			// VSRC003_LoadMotion():  Specified file not found
	ERR_MOTION_UNKNOWNFORMAT=2,		// VSRC003_LoadMotion():  Failed to load motion file
	ERR_COMMUNICATE=3,				// Failed to communicate with CPU board
	ERR_PLAYINGMOTION=4,			// VSRC003_GetStatus(),VSRC003_LoadMotion(),VSRC003_PlayMotion():  Still playing the motion
	ERR_IMPROPER_MEMORY_ACCESS=5	// Improper Memorry access
} ERRTYPE;

#define	ENDLESS	-1					// VSRC003_PlayMotion():  -1 is used for infinit loop


/*********************************************************
EXPORT int VSRC003_LoadMotion(TCHAR *filemame)
	It will load motion file onto the RAM of VS-RC003 
	ArgumentsF
		TCHAR *filemame (file name including path from your out dir) 
	Return Value: 
		If there is no error, it returns 0; 
		otherwise, returns ERRTYPE
		If you call this function while playing previous motion requested, it will return ERR_PLAYINGMOTION
		If the communication fails, it will return ERR_COMMUNICATION
**********************************************************/
EXPORT int VSRC003_LoadMotion(TCHAR *filemame);


/*********************************************************
EXPORT int VSRC003_PlayMotion(int loopnumber);
	It will play motion file loaded onto the RAM of VS-RC003 for number of times specified. 
	ArgumentsF
		int loopnumber:  number of times motion will be played, 
			-1 for infinit loop.
	Return Value: 
		If there is no error, it returns 0; 
		otherwise, returns ERRTYPE
		If you call this function while playing previous motion requested, it will return ERR_PLAYINGMOTION
		If the communication fails, it will return ERR_COMMUNICATION
**********************************************************/
EXPORT int VSRC003_PlayMotion(int loopnumber);


/*********************************************************
EXPORT int VSRC003_StopMotion();
	It will stop playing the motion at the next "break" sequence.
	If you have a loop block inside motion, it will break the loop.
	ArgumentsF
		None 
	Return Value: 
		If there is no error, it returns 0
		if the communication fails, it will return ERR_COMMUNICATION
**********************************************************/
EXPORT int VSRC003_StopMotion();

/*********************************************************
EXPORT int VSRC003_CancelMotion();
	It will stop playing motion. 
	Unlike VSRC003_StopMotion(), it will not wait for next "break".  It will stop motion imidiately.
	ArgumentsF
		None
	Return Value: 
		If there is no error, it returns 0
		If the communication fails, it will return ERR_COMMUNICATION
**********************************************************/
EXPORT int VSRC003_CancelMotion();


/*********************************************************
EXPORT int VSRC003_GetStatus();
	It will check if the motion is still playing or not.
	ArgumentsF
		None
	Return Value: 
		If the motion is not playing, it returns 0
		If it's still playing the motion, it will return ERR_PLAYINGMOTION
		If the communication fails, it will return ERR_COMMUNICATION
**********************************************************/
EXPORT int VSRC003_GetStatus();


/*********************************************************
EXPORT short VSRC003_GetValue(int valuenumber);
	It will read value of variable defined in memory space of CPU board.
	ArgumentsF
		valuenumber:  location of value you want to read.  
		It coresponds to the variable number listed in memory map.
	Return Value: 
		the value of requested variable
**********************************************************/
EXPORT short VSRC003_GetValue(int valuenumber);


/*********************************************************
EXPORT int VSRC003_SetValue(int valuenumber, short value);
	It will set a value into the specified memory space of CPU board.
	ArgumentsF
		valuenumber:  location of value you want to read. It coresponds to the variable number listed in memory map.
		value:  value will be written.
	Return Value: 
		If the motion is not playing, it returns 0
		If the communication fails, it will return ERR_COMMUNICATION
**********************************************************/
EXPORT int VSRC003_SetValue(int valuenumber, short value);


/*********************************************************
EXPORT int VSRC003_GetStatus();
	It will manage the power of the servo motor.
	ArgumentsF
		int poweron_off:  1 for on, 0 for off
	Return Value: 
		If the motion is not playing, it returns 0
		If the communication fails, it will return ERR_COMMUNICATION
**********************************************************/
EXPORT int VSRC003_ServoPower(int poweron_off);
